@@ -1,5 +1,4 @@
 # flake8: noqa
-from .elmo import Elmo
 from .pattern_search import PatternSearcher
 from .regex_ruler import MultipleRegexRuler, RegexRuler
 from .transformers import (
@@ -9,4 +8,3 @@ from .transformers import (
     TrfModel,
     TrfTokenizer,
 )
-from .udify import Udify, load_udify
