@@ -1,15 +1,32 @@
 """Defines pattern search pipeline based on ahocorasik."""
-from typing import Callable, Dict, Iterable, Iterator, List, Optional, Tuple, cast
+from typing import (
+    Callable,
+    Dict,
+    Iterable,
+    Iterator,
+    List,
+    Optional,
+    Tuple,
+    Union,
+    cast,
+)
 
 import ahocorasick
 import spacy
 import textspan
 from spacy.tokens import Doc
+from spacy.tokens.span import Span
 from spacy.util import filter_spans
 from typing_extensions import Literal
 
 from camphr.utils import SerializationMixin, get_doc_char_span
 
+# Sometimes matched text is different from original text
+# since `PatternSearcher` can match the `lemma`.
+# This extension holds the matched text.
+PATTERN_MATCH_AS = "pattern_match_as"
+Span.set_extension(PATTERN_MATCH_AS, default=None, force=True)
+
 
 @spacy.component("pattern_searcher")
 class PatternSearcher(SerializationMixin):
@@ -36,6 +53,7 @@ class PatternSearcher(SerializationMixin):
         destructive: bool = False,
         lower: bool = False,
         normalizer: Optional[Callable[[str], str]] = None,
+        lemma: bool = False,
         **cfg
     ):
         self.model = model
@@ -47,6 +65,7 @@ class PatternSearcher(SerializationMixin):
         self.lower = lower
         self.cfg = cfg
         self.normalizer = normalizer
+        self.lemma = lemma
 
         if custom_label:
             self.label_type = "custom_label"
@@ -104,8 +123,11 @@ class PatternSearcher(SerializationMixin):
             i = j - len(word) + 1
             yield i, j + 1, word
 
-    def _to_text(self, doc: Doc) -> str:
-        text = doc.text
+    def _to_text(self, doc: Union[Doc, Span]) -> str:
+        if self.lemma:
+            text = _to_lemma_text(doc)
+        else:
+            text = doc.text
         if self.lower:
             text = text.lower()
         if self.normalizer:
@@ -121,9 +143,15 @@ class PatternSearcher(SerializationMixin):
             if i is None or j is None:
                 continue
             span = get_doc_char_span(
-                doc, i, j, destructive=self.destructive, label=self.get_label(text)
+                doc,
+                i,
+                j,
+                destructive=self.destructive,
+                covering=not self.destructive,
+                label=self.get_label(text),
             )
-            if span:
+            if span and self._to_text(span) == text:
+                span._.set(PATTERN_MATCH_AS, text)
                 spans.append(span)
         [s.text for s in spans]  # TODO: resolve the evaluation bug and remove this line
         ents = filter_spans(doc.ents + tuple(spans))
@@ -131,6 +159,14 @@ class PatternSearcher(SerializationMixin):
         return doc
 
 
+def _to_lemma_text(doc: Union[Doc, Span]) -> str:
+    ret = ""
+    for token in doc:
+        ret += token.lemma_
+        ret += token.whitespace_
+    return ret
+
+
 def _modify_spans(
     matches: List[Tuple[int, int, str]], text: str, original_text: str
 ) -> Iterator[Tuple[Optional[int], Optional[int], str]]:
