@@ -205,6 +205,7 @@ class LabelsMixin:
 
     @property
     def label_weights(self: PipeProtocol) -> torch.Tensor:
+        # TODO remove all type: ignore
         if not hasattr(self, "_label_weights"):
             weights_map = self.cfg.get(LABEL_WEIGHTS)
             weights = torch.ones(len(self.label2id))  # type: ignore
@@ -212,7 +213,7 @@ class LabelsMixin:
                 assert len(weights_map) == len(self.label2id)  # type: ignore
                 for k, v in weights_map.items():
                     weights[self.label2id[k]] = v  # type: ignore
-            self._label_weights = weights
+            self._label_weights = weights  # type: ignore
         return self._label_weights  # type: ignore
 
     def convert_label(self: UserHooksMixin, label: str) -> str:  # type:ignore
@@ -344,9 +345,7 @@ class TransformersInput:
     input_ids: torch.Tensor
     token_type_ids: torch.Tensor
     attention_mask: torch.Tensor
-    input_len: torch.LongTensor
-    overflowing_tokens: Optional[torch.LongTensor] = None
-    num_truncated_tokens: int = 0
+    special_tokens_mask: Optional[torch.Tensor] = None
 
     def __iter__(self) -> Iterator["TransformersInput"]:
         for i in range(len(cast(Sized, self.input_ids))):
@@ -370,5 +369,4 @@ class TransformersInput:
     @property
     def model_input(self) -> Dict[str, torch.Tensor]:
         output = {k: getattr(self, k) for k in self.tensor_field_names}
-        del output["input_len"]
         return output
